@@ -26,13 +26,6 @@ class Compress:
         self.path_nodes = self.root.findall('.//%spath' %(tag_prefix))
         self.path_parents = self.root.findall('.//%spath/..' %(tag_prefix))
         self.paths = list()
-#         for p in self.path_nodes:
-#             try:
-#                 self.paths.append(svg.path.parse_path(p.attrib['d']))
-#             except KeyError, e:
-#                 # Items such as clipping paths have no coordinates
-#                 warnings.warn('Detected path with no coordinates: e.message')
-#                 pass
         self.paths = [svg.path.parse_path(p.attrib.get('d', 'M 0,0 z')) for p in self.path_nodes]
         
     def linearize_paths(self, curve_fidelity = 10):
@@ -295,14 +288,13 @@ def test(filename, thresholds = (5, 2), epsilon = 0.5, curve_fidelity = 10,
     ## Compress by unification:
     outputfile = ''.join((filestr, '_merged.', extension))
     compress_by_method(filename, 'merge', curve_fidelity, outputfile, pre_select = True, 
-                       selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon,
-                       group_by_color = False)
+                       selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon)
 
     ## Compress by convex hull:
     outputfile = ''.join((filestr, '_hull.', extension))
     compress_by_method(filename, 'merge', curve_fidelity, outputfile, pre_select = True, 
                        selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon, 
-                       bufferDistance = buffer_distance, operation_key = 'hull', group_by_color = False)
+                       bufferDistance = buffer_distance, operation_key = 'hull')
     
     ## Lastly, see if uncompressed file is same as original:
     # TODO: Find out why wierdly, it never is.
